@@ -1,7 +1,7 @@
 /*
  * Seahorse
  *
- * Copyright (C) 2006 Nate Nielsen
+ * Copyright (C) 2006 Stefan Walter
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -54,7 +54,7 @@ static const GOptionEntry options[] = {
         N_("Print variables in for a C type shell"), NULL },
 
     { "variables", 'v', 0, G_OPTION_ARG_NONE, &seahorse_agent_displayvars, 
-        N_("Display variables instead of editing conf files (gpg.conf, SSH agent socket)"), NULL },
+        N_("Display variables instead of editing gpg.conf file"), NULL },
 
     { "execute", 'x', 0, G_OPTION_ARG_NONE, &seahorse_agent_execvars, 
         N_("Execute other arguments on the command line"), NULL },
@@ -112,7 +112,6 @@ daemonize (gchar **exec)
 
     /* Let the agent do it's thing */
     seahorse_agent_postfork (pid);
-    seahorse_agent_ssh_postfork (pid);
     
     if (agent_no_daemonize) {
 
@@ -210,21 +209,11 @@ int main(int argc, char* argv[])
     GnomeClient *client = NULL;
     GOptionContext *octx = NULL;
 
-    seahorse_secure_memory_init (65536);
+    seahorse_secure_memory_init ();
     
-    /* We need to drop privileges completely for security */
-#if defined(HAVE_SETRESUID) && defined(HAVE_SETRESGID)
-
-    /* Not in header files for all OSs, even where present */
-    int setresuid(uid_t ruid, uid_t euid, uid_t suid);
-    int setresgid(gid_t rgid, gid_t egid, gid_t sgid);
-  
-    if (setresuid (getuid (), getuid (), getuid ()) == -1 ||
-        setresgid (getgid (), getgid (), getgid ()) == -1)
-#else
-    if (setuid (getuid ()) == -1 || setgid (getgid ()) == -1)
-#endif
-        err (1, _("couldn't drop privileges properly"));
+    bindtextdomain (GETTEXT_PACKAGE, LOCALEDIR);
+    bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+    textdomain (GETTEXT_PACKAGE);
     
     octx = g_option_context_new ("");
     g_option_context_add_main_entries (octx, options, GETTEXT_PACKAGE);
@@ -235,7 +224,6 @@ int main(int argc, char* argv[])
                     GNOME_PARAM_APP_DATADIR, DATA_DIR, NULL);
 
     seahorse_agent_prefork ();
-    seahorse_agent_ssh_prefork ();
 
     if (seahorse_agent_execvars && 
         (!agent_exec_args || !agent_exec_args[0]))
@@ -274,10 +262,6 @@ int main(int argc, char* argv[])
     
     if (!seahorse_agent_init ())
         seahorse_agent_uninit ();
-#ifdef WITH_SSH
-    if (!seahorse_agent_ssh_init ())
-        seahorse_agent_ssh_uninit ();
-#endif
     
     /* Sometimes we've already gotten a quit signal */
     if(!agent_quit) {
@@ -288,9 +272,6 @@ int main(int argc, char* argv[])
 
     /* And now clean them all up */
     seahorse_agent_uninit ();
-#ifdef WITH_SSH
-    seahorse_agent_ssh_uninit ();
-#endif
     
     seahorse_context_destroy (SCTX_APP ());
 
